import { createStore } from 'vuex';
import axios from "axios";
import Helper from "../config/helperConfig";
import * as skyid from 'skyid-sdk-web';

export default createStore({
    state() {
        return {
            response_data: null,
            bearToken: null,
            response_ocr: null,
            response_liveness: null,
            response_facematching: null,
            parameters_web_sdk: null,
        };
      },
      mutations: {
        SET_REPONSE_DATA(state, response_data) {
            state.response_data = response_data;
        },  
        SET_BEARTOKEN(state, bearToken) {
            state.bearToken = bearToken;
        },
        SET_RESPONSE_OCR(state, response_ocr) {
            state.response_ocr = response_ocr;
        },
        SET_RESPONSE_LIVENESS(state, response_liveness) {
            state.response_liveness = response_liveness;
        },
        SET_PARAMETERS_WEBSDK(state, parameters_web_sdk) {
          state.parameters_web_sdk = parameters_web_sdk;
        },
        SET_FACEMATCHING(state, response_facematching) {
          state.response_facematching = response_facematching;
        }
      },
      actions: {
        login({ commit, dispatch}) {
            const formData = new FormData()
            formData.append("username", Helper.skyid_fa_sdk_user);
            formData.append("password", Helper.skyid_fa_sdk_password);
            return new Promise((resolve, reject) => {
              axios.post(Helper.API_url, formData, {
                headers: {
                    'Content-Type': 'multipart/form-data',
                  }
              })
              .then(response => {
                // traiter la réponse
                const response_data = response.data;
                commit('SET_REPONSE_DATA', response_data);
                commit('SET_BEARTOKEN', response_data.response_data.access_token);
                resolve(response);
                return dispatch('get_parameters_web_sdk', { bearToken: response_data.response_data.access_token });
              })
              .catch(error => {
                // traiter l'erreur
                reject(error);
                console.log(error)
              });
            });
          },
          get_parameters_web_sdk({ commit }, payload) {
            const { bearToken } = payload;
            const formData = new FormData()
            formData.append("token", Helper.skyid_fa_sdk_token);
            formData.append("application_id", Helper.skyid_fa_sdk_appId);
            return new Promise((resolve, reject) => {
              axios.post(Helper.SKYID_FA_SDK_PARAMS_url, formData, {
                headers: {
                  Authorization: `Bearer ${bearToken}`,
                  'Content-Type': 'multipart/form-data',
                }
              })
              .then(response => {
                // traiter la réponse
                const response_data = response.data;
                commit('SET_PARAMETERS_WEBSDK', response_data.response_data);
                skyid.skyid_fa_init_sdk(response_data.response_data);
                resolve(response);
              })
              .catch(error => {
                // traiter l'erreur
                reject(error);
                console.log(error)
              });
            });
          },
          skyid_extract_info_from_doc_request({ commit }, payload){
            const { myImage, bearToken } = payload;
            const formData = new FormData()
            formData.append("token", Helper.skyid_fa_sdk_token);
            formData.append("document", myImage);
            formData.append('institution_id',"042");
            formData.append('application_id', Helper.skyid_fa_sdk_appId);
            formData.append('channel_id',"02");
            formData.append('service_id',"01");
            formData.append('sub_service_id',"0005");
            formData.append("request_data",'{"doc_type":"01"}');
            return new Promise((resolve, reject) => {
              axios.post(Helper.OCR_url, formData, {
                headers: {
                    Authorization: `Bearer ${bearToken}`,
                    'Content-Type': 'multipart/form-data',
                  }
              })
              .then(response => {
                // traiter la réponse
                const response_ocr = response;
                commit('SET_RESPONSE_OCR', response_ocr.data);
                resolve(response);
              })
              .catch(error => {
                // traiter l'erreur
                reject(error);
                console.log(error)
              });
            });
          },
          skyid_fa_check_liveness_request({ commit }, payload){
            const { myImage, bearToken } = payload;
            const formData = new FormData()
            formData.append("selfie",myImage);
            return new Promise((resolve, reject) => {
              axios.post(Helper.LIVENESS_url, formData, {
                headers: {
                    Authorization: `Bearer ${bearToken}`,
                    'Content-Type': 'multipart/form-data',
                  }
              })
              .then(response => {
                // traiter la réponse
                const response_ocr = response;
                commit('SET_RESPONSE_LIVENESS', response_ocr.data);
                resolve(response);
              })
              .catch(error => {
                // traiter l'erreur
                reject(error);
                console.log(error)
              });
            });
          },
          skyid_fa_face_scan_end_callbackfacematching({ commit }, payload){
            const { docImage, face_image, guid,bearToken } = payload;
            const formData = new FormData()
            formData.append("doc_1_1", docImage);
            formData.append("slf_1", face_image);
            formData.append('guid', guid);
            formData.append("token", Helper.skyid_fa_sdk_token);
            formData.append("application_id", Helper.skyid_fa_sdk_appId);
            return new Promise((resolve, reject) => {
              axios.post(Helper.FACE_MATCHING_url, formData, {
                headers: {
                    Authorization: `Bearer ${bearToken}`,
                    'Content-Type': 'multipart/form-data',
                  }
              })
              .then(response => {
                // traiter la réponse
                const response_facematching = response;
                commit('SET_FACEMATCHING', response_facematching.data);
                resolve(response);
              })
              .catch(error => {
                // traiter l'erreur
                reject(error);
                console.log(error)
              });
            });
          }
      },
      getters: {
        response_data(state) {
            return state.response_data;
        },
        bearToken(state) {
            return state.bearToken;
        },
        response_ocr(state) {
            return state.response_ocr;
        },
        parameters_web_sdk(state){
          return state.parameters_web_sdk;
        },
        response_liveness(state) {
            return state.response_liveness;
        },
        response_facematching(state) {
          return state.response_facematching;
        }
      },
});
